Skip to main content

ExtensiveAutomation Agent

PyPI - Python Version

agent for the extensive automation server.

Table of contents

Agent Installation

About agents

Agents enable to execute remotely your workflow. It's can be useful on some cases to run them from different machine that your extensive automation server.

PyPI package

  1. Run the following command

    python3 -m pip install extensiveautomation_agent
    
  2. Type the following command on your shell to start the server

    extensiveautomation_agent --help
    Usage: extensiveautomation_agent.py [options]
    
    Options:
    -h, --help         show this help message and exit
    --verbose          Verbose mode
    --remote=REMOTE    Server host address (default=127.0.0.1)
    --port=PORT        Server port (optional default=8083)
    --token=TOKEN      Token agent
    --proxy=PROXY      Proxy address:port (optional)
    
  3. The next step is to install one or more plugins

Source code

  1. Clone this repository on your linux server

    git clone https://github.com/ExtensiveAutomation/extensiveautomation-agent.git
    cd extensiveautomation-agent/
    
  2. Show usage documentation.

    cd src/
    python3 extensiveautomation_agent.py --help
    
  3. The next step is to install one or more plugins

Install plugins

By default the agent binary comes without plugins so you need to install them one by one according to your needs. The installation can be done with the pip command.

Take a look to the table below to see the correspondence between the agents plugins you want to use and the plugin to deploy on server side too.

Agent Plugins Description Server Plugins (must have)
curl send http requests and analyze http responses plugin-web
ssh communicate with remote server through SSH plugin-cli
selenium3 interact with a selenium server plugin-gui
sikulix run sikulix commands plugin-gui

Agent Deployment

Generate token

A token is mandatory to connect a remote agent to your automation server.

  1. Connect on your automation server

  2. Executes the following command

extensiveautomation --generate-token agent01.curl
agent01.curl 0bb2705c-9860-445b-b0fc-44b552476cb3
  1. Save the token generated and reload the server
extensiveautomation --reload

Running agent

Running agent is easy but before

  • you must install the good plugin according to your needs
  • generate a token for your agent
  • register then on the server

After that you can execute the following command:

extensiveautomation_agent --remote=10.0.0.100 --token=13ae34f7-e2f6-40b6-9c87-6c275423127e --curl
2020-07-26 10:28:09,513 starting agent curl ...
2020-07-26 10:28:09,877 agent registration successful

Metadata

Release files for extensiveautomation-agent 16.1.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for extensiveautomation-agent 16.1.0
File Size Uploaded
extensiveautomation_agent-16.1.0.tar.gz 28.7 kB Details

Release files / extensiveautomation_agent-16.1.0.tar.gz

Download URL extensiveautomation_agent-16.1.0.tar.gz
Size 28.7 kB
Tags Source
SHA-256 checksum
How to use checksums
66f72f625cb6fc11a1e47083640661518bd93466c9df8234f11876ab4ea0af68
BLAKE2b-256 checksum
How to use checksums
78e59a689fb108087d5a4bf19421626e233b22d578b54addb4da36d971177eec
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.2.0 pkginfo/1.5.0.1 requests/2.23.0 setuptools/47.1.0 requests-toolbelt/0.9.1 tqdm/4.48.0 CPython/3.7.8

Release history Release notifications | RSS feed

16.2.0

1 release file

This release

16.1.0 This release

1 release file

16.0.3

1 release file

16.0.2

1 release file

16.0.1

1 release file

16.0.0

1 release file

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page